aboutsummaryrefslogtreecommitdiffstats
path: root/ui
diff options
context:
space:
mode:
Diffstat (limited to 'ui')
-rw-r--r--ui/qt/follow_stream_dialog.cpp12
-rw-r--r--ui/qt/main_window.cpp4
-rw-r--r--ui/qt/main_window.h4
-rw-r--r--ui/qt/main_window.ui12
-rw-r--r--ui/qt/main_window_slots.cpp14
-rw-r--r--ui/qt/packet_list.cpp2
-rw-r--r--ui/qt/proto_tree.cpp2
-rw-r--r--ui/qt/uat_dialog.cpp2
-rw-r--r--ui/qt/uat_frame.cpp2
9 files changed, 27 insertions, 27 deletions
diff --git a/ui/qt/main_window.cpp b/ui/qt/main_window.cpp
index d21a53ca85..a3516dbe5d 100644
--- a/ui/qt/main_window.cpp
+++ b/ui/qt/main_window.cpp
@@ -2286,7 +2286,7 @@ void MainWindow::setMenusForCaptureFile(bool force_disable)
main_ui_->actionFileExportPacketBytes->setEnabled(enable);
main_ui_->actionFileExportPDU->setEnabled(enable);
- main_ui_->actionFileExportSSLSessionKeys->setEnabled(enable);
+ main_ui_->actionFileExportTLSSessionKeys->setEnabled(enable);
foreach (QAction *eo_action, main_ui_->menuFileExportObjects->actions()) {
eo_action->setEnabled(enable);
@@ -2316,7 +2316,7 @@ void MainWindow::setMenusForCaptureInProgress(bool capture_in_progress) {
main_ui_->actionFileExportPacketBytes->setEnabled(capture_in_progress);
main_ui_->actionFileExportPDU->setEnabled(!capture_in_progress);
- main_ui_->actionFileExportSSLSessionKeys->setEnabled(capture_in_progress);
+ main_ui_->actionFileExportTLSSessionKeys->setEnabled(capture_in_progress);
foreach (QAction *eo_action, main_ui_->menuFileExportObjects->actions()) {
eo_action->setEnabled(capture_in_progress);
diff --git a/ui/qt/main_window.h b/ui/qt/main_window.h
index fc8f923fd4..b732bcf82a 100644
--- a/ui/qt/main_window.h
+++ b/ui/qt/main_window.h
@@ -442,7 +442,7 @@ private slots:
void on_actionFilePrint_triggered();
void on_actionFileExportPDU_triggered();
- void on_actionFileExportSSLSessionKeys_triggered();
+ void on_actionFileExportTLSSessionKeys_triggered();
void actionEditCopyTriggered(MainWindow::CopySelected selection_type);
void on_actionCopyAllVisibleItems_triggered();
@@ -546,7 +546,7 @@ private slots:
void openFollowStreamDialog(follow_type_t type, int stream_num = -1);
void on_actionAnalyzeFollowTCPStream_triggered();
void on_actionAnalyzeFollowUDPStream_triggered();
- void on_actionAnalyzeFollowSSLStream_triggered();
+ void on_actionAnalyzeFollowTLSStream_triggered();
void on_actionAnalyzeFollowHTTPStream_triggered();
void statCommandExpertInfo(const char *, void *);
void on_actionAnalyzeExpertInfo_triggered();
diff --git a/ui/qt/main_window.ui b/ui/qt/main_window.ui
index 573f480cfb..31c3135bf4 100644
--- a/ui/qt/main_window.ui
+++ b/ui/qt/main_window.ui
@@ -197,7 +197,7 @@
<addaction name="menuFileExportPacketDissections"/>
<addaction name="actionFileExportPacketBytes"/>
<addaction name="actionFileExportPDU"/>
- <addaction name="actionFileExportSSLSessionKeys"/>
+ <addaction name="actionFileExportTLSSessionKeys"/>
<addaction name="menuFileExportObjects"/>
<addaction name="separator"/>
<addaction name="actionFilePrint"/>
@@ -425,7 +425,7 @@
</property>
<addaction name="actionAnalyzeFollowTCPStream"/>
<addaction name="actionAnalyzeFollowUDPStream"/>
- <addaction name="actionAnalyzeFollowSSLStream"/>
+ <addaction name="actionAnalyzeFollowTLSStream"/>
<addaction name="actionAnalyzeFollowHTTPStream"/>
</widget>
<widget class="QMenu" name="menuConversationFilter">
@@ -1177,9 +1177,9 @@
<string notr="true">Ctrl+Shift+X</string>
</property>
</action>
- <action name="actionFileExportSSLSessionKeys">
+ <action name="actionFileExportTLSSessionKeys">
<property name="text">
- <string>Export SSL Session Keys…</string>
+ <string>Export TLS Session Keys…</string>
</property>
</action>
<action name="actionFilePrint">
@@ -1790,12 +1790,12 @@
<string notr="true">Ctrl+Alt+Shift+U</string>
</property>
</action>
- <action name="actionAnalyzeFollowSSLStream">
+ <action name="actionAnalyzeFollowTLSStream">
<property name="enabled">
<bool>false</bool>
</property>
<property name="text">
- <string>SSL Stream</string>
+ <string>TLS Stream</string>
</property>
<property name="shortcut">
<string notr="true">Ctrl+Alt+Shift+S</string>
diff --git a/ui/qt/main_window_slots.cpp b/ui/qt/main_window_slots.cpp
index ef03920384..6bafd44275 100644
--- a/ui/qt/main_window_slots.cpp
+++ b/ui/qt/main_window_slots.cpp
@@ -1215,7 +1215,7 @@ void MainWindow::setMenusForSelectedPacket()
main_ui_->actionAnalyzeFollowTCPStream->setEnabled(is_tcp);
main_ui_->actionAnalyzeFollowUDPStream->setEnabled(is_udp);
- main_ui_->actionAnalyzeFollowSSLStream->setEnabled(is_ssl);
+ main_ui_->actionAnalyzeFollowTLSStream->setEnabled(is_ssl);
main_ui_->actionAnalyzeFollowHTTPStream->setEnabled(is_http);
foreach (QAction *cc_action, cc_actions) {
@@ -1824,7 +1824,7 @@ void MainWindow::on_actionFileExportPDU_triggered()
exportpdu_dialog->activateWindow();
}
-void MainWindow::on_actionFileExportSSLSessionKeys_triggered()
+void MainWindow::on_actionFileExportTLSSessionKeys_triggered()
{
QString file_name;
QString save_title;
@@ -1837,17 +1837,17 @@ void MainWindow::on_actionFileExportSSLSessionKeys_triggered()
QMessageBox::warning(
this,
tr("No Keys"),
- tr("There are no SSL Session Keys to save."),
+ tr("There are no TLS Session Keys to save."),
QMessageBox::Ok
);
return;
}
- save_title.append(wsApp->windowTitleString(tr("Export SSL Session Keys (%Ln key(s))", "", keylist_len)));
+ save_title.append(wsApp->windowTitleString(tr("Export TLS Session Keys (%Ln key(s))", "", keylist_len)));
file_name = WiresharkFileDialog::getSaveFileName(this,
save_title,
wsApp->lastOpenDir().canonicalPath(),
- tr("SSL Session Keys (*.keys *.txt);;All Files (" ALL_FILES_WILDCARD ")")
+ tr("TLS Session Keys (*.keys *.txt);;All Files (" ALL_FILES_WILDCARD ")")
);
if (file_name.length() > 0) {
gchar *keylist;
@@ -2776,9 +2776,9 @@ void MainWindow::on_actionAnalyzeFollowUDPStream_triggered()
openFollowStreamDialog(FOLLOW_UDP);
}
-void MainWindow::on_actionAnalyzeFollowSSLStream_triggered()
+void MainWindow::on_actionAnalyzeFollowTLSStream_triggered()
{
- openFollowStreamDialog(FOLLOW_SSL);
+ openFollowStreamDialog(FOLLOW_TLS);
}
void MainWindow::on_actionAnalyzeFollowHTTPStream_triggered()
diff --git a/ui/qt/packet_list.cpp b/ui/qt/packet_list.cpp
index 71f60f2bf1..6aa804d179 100644
--- a/ui/qt/packet_list.cpp
+++ b/ui/qt/packet_list.cpp
@@ -566,7 +566,7 @@ void PacketList::contextMenuEvent(QContextMenuEvent *event)
ctx_menu_.addMenu(submenu);
submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowTCPStream"));
submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowUDPStream"));
- submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowSSLStream"));
+ submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowTLSStream"));
submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowHTTPStream"));
ctx_menu_.addSeparator();
diff --git a/ui/qt/proto_tree.cpp b/ui/qt/proto_tree.cpp
index e333926d43..22a6978ce4 100644
--- a/ui/qt/proto_tree.cpp
+++ b/ui/qt/proto_tree.cpp
@@ -140,7 +140,7 @@ void ProtoTree::contextMenuEvent(QContextMenuEvent *event)
ctx_menu_.addMenu(submenu);
submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowTCPStream"));
submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowUDPStream"));
- submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowSSLStream"));
+ submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowTLSStream"));
submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowHTTPStream"));
ctx_menu_.addSeparator();
diff --git a/ui/qt/uat_dialog.cpp b/ui/qt/uat_dialog.cpp
index 8cbbddbfc6..669be66c6c 100644
--- a/ui/qt/uat_dialog.cpp
+++ b/ui/qt/uat_dialog.cpp
@@ -58,7 +58,7 @@ UatDialog::UatDialog(QWidget *parent, epan_uat *uat) :
// FIXME: this prevents the columns from being resized, even if the text
// within a combobox needs more space (e.g. in the USER DLT settings). For
- // very long filenames in the SSL RSA keys dialog, it also results in a
+ // very long filenames in the TLS RSA keys dialog, it also results in a
// vertical scrollbar. Maybe remove this since the editor is not limited to
// the column width (and overlays other fields if more width is needed)?
ui->uatTreeView->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
diff --git a/ui/qt/uat_frame.cpp b/ui/qt/uat_frame.cpp
index 84e8f18ac2..ed0e5f8916 100644
--- a/ui/qt/uat_frame.cpp
+++ b/ui/qt/uat_frame.cpp
@@ -49,7 +49,7 @@ UatFrame::UatFrame(QWidget *parent) :
// FIXME: this prevents the columns from being resized, even if the text
// within a combobox needs more space (e.g. in the USER DLT settings). For
- // very long filenames in the SSL RSA keys dialog, it also results in a
+ // very long filenames in the TLS RSA keys dialog, it also results in a
// vertical scrollbar. Maybe remove this since the editor is not limited to
// the column width (and overlays other fields if more width is needed)?
ui->uatTreeView->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
diff --git a/ui/qt/follow_stream_dialog.cpp b/ui/qt/follow_stream_dialog.cpp
index 2b141fbeb1..c039877100 100644
--- a/ui/qt/follow_stream_dialog.cpp
+++ b/ui/qt/follow_stream_dialog.cpp
@@ -85,8 +85,8 @@ FollowStreamDialog::FollowStreamDialog(QWidget &parent, CaptureFile &cf, follow_
case FOLLOW_TCP:
follower_ = get_follow_by_name("TCP");
break;
- case FOLLOW_SSL:
- follower_ = get_follow_by_name("SSL");
+ case FOLLOW_TLS:
+ follower_ = get_follow_by_name("TLS");
break;
case FOLLOW_UDP:
follower_ = get_follow_by_name("UDP");
@@ -455,7 +455,7 @@ FollowStreamDialog::readStream()
case FOLLOW_TCP :
case FOLLOW_UDP :
case FOLLOW_HTTP :
- case FOLLOW_SSL :
+ case FOLLOW_TLS :
ret = readFollowStream();
break;
@@ -802,9 +802,9 @@ bool FollowStreamDialog::follow(QString previous_filter, bool use_stream_index,
return false;
}
- if (follow_type_ == FOLLOW_SSL || follow_type_ == FOLLOW_HTTP)
+ if (follow_type_ == FOLLOW_TLS || follow_type_ == FOLLOW_HTTP)
{
/* we got ssl/http so we can follow */
removeStreamControls();
}
@@ -868,7 +868,7 @@ bool FollowStreamDialog::follow(QString previous_filter, bool use_stream_index,
break;
}
- case FOLLOW_SSL:
+ case FOLLOW_TLS:
case FOLLOW_HTTP:
/* No extra handling */
break;
@@ -802,9 +802,9 @@ bool FollowStreamDialog::follow(QString previous_filter, bool use_stream_index,
{
- /* we got ssl/http so we can follow */
+ /* we got tls/http so we can follow */
removeStreamControls();
}